@@ -9,7 +9,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: filesystem.c,v 1.3 2005/02/27 19:04:32 lav Exp $
+    $Id: filesystem.c,v 1.4 2005/03/02 18:22:29 lav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -90,7 +90,7 @@ const char *natspec_get_filename_encoding(const char *locale)
 	/* Try get from environment variable */
 	const char *buf = getenv("G_FILENAME_ENCODING");
     /* FIXME: test for comma-separated list in G_FILENAME_ENCODING */
-	if (buf != NULL && buf[0] != '\0')
+	if (buf != NULL && locale != NULL && locale[0] == '\0' /*&& natspec_check_charset(NATSPEC_UNIXCS, buf)*/)
 	{
 		/* If get from env non empty string,
 		   search in static table the same name: normalized */
